import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom
} from 'd3';
import { dropdownMenu } from './dropdownMenu';
import { scatterPlot } from './scatterPlot';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

let data;
let xColumn;
let yColumn;

const onXColumnClicked = column => {
  xColumn = column;
  render();
};

const onYColumnClicked = column => {
  yColumn = column;
  render();
};

const render = () => {
  
  select('#x-menu')
    .call(dropdownMenu, {
      options: data.columns,
      onOptionClicked: onXColumnClicked,
      selectedOption: xColumn
    });
  
  select('#y-menu')
    .call(dropdownMenu, {
      options: data.columns,
      onOptionClicked: onYColumnClicked,
      selectedOption: yColumn
    });
  
  svg.call(scatterPlot, {
    xValue: d => d.ds_pm_pred,
    xAxisLabel: 'PM2.5 micrograms per cubic meter',
    yValue: d => d[yColumn],
    circleRadius: 5,
    yAxisLabel: yColumn,
    margin: { top: 80, right: 60, bottom: 88, left: 150 },
    width,
    height,
    data
  });
};

csv('data.csv')
  .then(loadedData => {
    data = loadedData;
    data.forEach(d => {
			d.ds_pm_pred = +d.ds_pm_pred;
   		d.MdnHHIncome = +d.MdnHHIncome;
    	d.PercBlwPvrty = +d.PercBlwPvrty;
      d.MdnFmlyIncme = +d.MdnFmlyIncme;
      d.Perc_NoHlthInsrnceCvrge = +d.Perc_NoHlthInsrnceCvrge;
    });
    xColumn = data.columns[5];
    yColumn = data.columns[6];
    render();
  });